# package-lfcayres

Description. 
The package package-lfcayres is used to:
	Processing:
		- Histogram matching 
		- Structural similarity
		- Resize image
	Utils:
		- Read image
		- Save image
		- Plot image
		- Plot result
		- Plot histogram

	
	## Installation

Use the package manager [pip](https://pip.pypa.io/en/stable/) to install package-lfcayres

```bash
pip install package-lfcayres
```



## Author
Luiz Felipe Cayres Vieira

## License
[MIT](https://choosealicense.com/licenses/mit/)